@@ -270,6 +270,8 @@ class Model:
         for range in self.__worksheet.merged_cells.ranges:
             self.__mergedcells.append(Variable(str(range), None, None, range))
 
+        self.__pagemargins = self.__worksheet.page_margins
+        self.__pagesetup = self.__worksheet.page_setup
         self.__data = Data()
 
     @property
@@ -405,6 +407,20 @@ class Model:
             rows_height.append([row.name, row.value])
         return rows_height
 
+    @property
+    def page_margins(self):
+        """
+        Documentation
+        """
+        return self.__pagemargins
+
+    @property
+    def page_setup(self):
+        """
+        Documentation
+        """
+        return self.__pagesetup
+
     @property
     def data(self):
         """
@@ -471,6 +487,8 @@ class Model:
                         self.__styles.append(Style(style.name,style.row+n+1,style.column,style.data_type, style.font, style.alignment,style.fill, style.border))
         for style in self.styles:
             style.rename()
+        worksheet.page_margins = self.page_margins
+        worksheet.page_setup = self.page_setup
         return None
 
     def update(self, data):
